import { getDirname, path } from '@vuepress/utils';
import chokidar from 'chokidar';
import { prepareSearchIndex } from './prepareSearchIndex.js';
const __dirname = getDirname(import.meta.url);
export const searchPlugin = ({ locales = {}, hotKeys = ['s', '/'], maxSuggestions = 5, isSearchable = () => true, getExtraFields = () => [], } = {}) => ({
    name: '@vuepress/plugin-search',
    clientConfigFile: path.resolve(__dirname, '../client/config.js'),
    define: {
        __SEARCH_LOCALES__: locales,
        __SEARCH_HOT_KEYS__: hotKeys,
        __SEARCH_MAX_SUGGESTIONS__: maxSuggestions,
    },
    onPrepared: async (app) => {
        await prepareSearchIndex({ app, isSearchable, getExtraFields });
    },
    onWatched: (app, watchers) => {
        // here we only watch the page data files
        // if the extra fields generated by `getExtraFields` are not included
        // in the page data, the changes may not be watched
        const searchIndexWatcher = chokidar.watch('internal/pageData/*', {
            cwd: app.dir.temp(),
            ignoreInitial: true,
        });
        searchIndexWatcher.on('add', () => {
            prepareSearchIndex({ app, isSearchable, getExtraFields });
        });
        searchIndexWatcher.on('change', () => {
            prepareSearchIndex({ app, isSearchable, getExtraFields });
        });
        searchIndexWatcher.on('unlink', () => {
            prepareSearchIndex({ app, isSearchable, getExtraFields });
        });
        watchers.push(searchIndexWatcher);
    },
});
